@@ -60,7 +60,7 @@ ggplot(mpg, aes(displ, hwy)) +
 
 ## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, hwy)) + 
-  stat_smooth(geom = GeomBlurrySmooth, size = 5, alpha = 1)
+  stat_smooth(geom = GeomBlurrySmooth, linewidth = 5, alpha = 1)
 
 ## -----------------------------------------------------------------------------
 ggplot(mpg, aes(displ, hwy)) + 
@@ -72,7 +72,7 @@ ggplot(mpg, aes(displ, hwy)) +
     id = 'draw_area'
   ) +
   with_mask(
-    stat_smooth(geom = GeomBlurrySmooth, size = 5, alpha = 1),
+    stat_smooth(geom = GeomBlurrySmooth, linewidth = 5, alpha = 1),
     mask = ch_alpha('draw_area')
   )
 
